EffectfulLayeredServer

Struct EffectfulLayeredServer 

pub struct EffectfulLayeredServer<A: ApiSpec, Provided, S> { /* private fields */ }
An effectful server with Tower middleware layers applied.

Created by EffectfulServer::layer. Supports further .provide(), .layer(), and .serve() calls.

Implementations

Source

impl<A: ApiSpec, P, S> EffectfulLayeredServer<A, P, S>

pub fn provide<E: Effect>(self) -> EffectfulLayeredServer<A, ECons<E, P>, S>

Declare that a middleware effect has been provided.

pub fn with_state<T: Clone + Send + Sync + 'static>(self, state: T) -> Self

Add shared state accessible via State<T> extractors.

pub fn max_body_size(self, max: usize) -> Self

Set the maximum request body size.

pub fn nest(self, prefix: &str) -> Self

Set a path prefix for all routes.

Source

impl<A: ApiSpec, P, S> EffectfulLayeredServer<A, P, S>
where S: Service<Request<Incoming>, Response = Response<BoxBody>, Error = Infallible> + Clone + Send + 'static, S::Future: Send + 'static,

pub fn layer<L>(self, layer: L) -> EffectfulLayeredServer<A, P, L::Service>
where L: Layer<S>, L::Service: Service<Request<Incoming>, Response = Response<BoxBody>, Error = Infallible> + Clone + Send + 'static, <L::Service as Service<Request<Incoming>>>::Future: Send + 'static,

Apply another Tower middleware layer.

Source

impl<A: ApiSpec, P, S> EffectfulLayeredServer<A, P, S>
where S: Service<Request<Incoming>, Response = Response<BoxBody>, Error = Infallible> + Clone + Send + 'static, S::Future: Send + 'static,

pub fn ready<Idx>(self) -> LayeredServer<S>
where A: AllProvided<P, Idx>,

Finalize into a LayeredServer.

Only compiles if all required effects have been provided.

pub async fn serve<Idx>( self, addr: SocketAddr, ) -> Result<(), Box<dyn Error + Send + Sync>>
where A: AllProvided<P, Idx>,

Start serving HTTP requests.

Only compiles if all required effects have been provided.

pub async fn serve_with_shutdown<Idx>( self, listener: TcpListener, shutdown: impl Future<Output = ()> + Send, ) -> Result<(), Box<dyn Error + Send + Sync>>
where A: AllProvided<P, Idx>,

Start serving with graceful shutdown.

Only compiles if all required effects have been provided.