pub trait StrictEndpoint {
type Inner: BindableEndpoint + HasResType;
}Expand description
Trait to extract binding info from a Strict endpoint.
pub trait StrictEndpoint {
type Inner: BindableEndpoint + HasResType;
}Trait to extract binding info from a Strict endpoint.